
===================================
Octavia Entity Relationship Diagram
===================================

Below is the current Octavia database data model.

* Solid stars are primary key columns.
* Hollow stars are foreign key columns.
* Items labeled as "PROPERTY" are data model relationships and are not
  present in the database.

.. only:: html

   Click to enlarge the diagram.

   .. image:: erd.svg
       :width: 660px
       :target: ../../_images/erd.svg

.. only:: latex

   .. image:: erd.svg
       :width: 660px
